@@ -23,6 +23,11 @@ def default(Strng):
 
     return Strng
 
+def KannadaSpacingCandrabindu(Strng):
+    Strng = Strng.replace('\u0C81', '\u0C80')
+
+    return Strng
+
 def KannadaNotRepha(Strng):
     ListC = "(" + "|".join(GM.CrunchSymbols(GM.Consonants, 'Kannada')) + ")"
 
@@ -397,18 +402,24 @@ def IASTLOCBurmeseSource(Strng):
         # Undo Replace subjoining forms: exp-virama + y/r/v/h <- subjoining y/r/v/h
         Strng = Strng.replace(virsub + x, y)
 
-    # u-Indep-i -> u-dep-i
-    Strng = Strng.replace('\u102Fဣ', '\u102D\u102F')
-
     # reverse replace vowel + diac with vowels
     vowDep = 'အော် အော အိ အီ အု အူ အေ'.split(' ')
     vowIndep = 'ဪ ဩ ဣ ဤ ဥ ဦ ဧ'.split(' ')
 
+    ## Fix modifier letter apostrephe to normal quotation mark
+    Strng = Strng.replace('ʼ', '’')
+
     for x, y in zip(vowDep, vowIndep):
-        Strng = Strng.replace('ʼ' + y, x)
+        Strng = Strng.replace('’' + y, x)
+
+    # u-Indep-i -> u-dep-i
+    Strng = Strng.replace('\u102Fဣ', '\u102D\u102F')
 
     # reverse mark a as glottalstop
-    Strng = Strng.replace('ʼအ', 'အ')
+    Strng = Strng.replace('’အ', 'အ')
+
+    # swap tone + virama to proper order
+    Strng = Strng.replace("့်", "့်")
 
     return Strng
 
@@ -424,13 +435,13 @@ def removeSegmentSpacesBurmese(Strng):
 def IASTLOCBurmeseTarget(Strng):
     #print(Strng)
     # mark tone
-    Strng = Strng.replace('˳', '´')
+    Strng = Strng.replace('˳', 'ʹ')
 
     # mark depaend au -> o'
     Strng = Strng.replace('auʻ','oʻ')
 
     # mark visarga as tone
-    Strng = Strng.replace('ḥ', '˝')
+    Strng = Strng.replace('ḥ', 'ʺ')
 
     # sort subjoined consonants
     # Strng = Strng.replace('‘‘', '')
@@ -446,7 +457,7 @@ def IASTLOCBurmeseTarget(Strng):
     for lat, bur in chars_misc.items():
         Strng = Strng.replace(bur, lat)
 
-    Strng = Strng.replace('ṃ', 'ṁ')
+    #Strng = Strng.replace('ṃ', 'ṁ')
 
     return Strng
 
@@ -458,12 +469,12 @@ def insertARomanSemitic(Strng):
     vowelsAll = '(' + '|'.join(GM.SemiticVowels) + ')'
     #print(Strng)
     Strng = re.sub(consonantsAll + '(?![꞉ʰ])(?!' + vowelsAll + ')', r'\1' + 'a', Strng)
-    Strng = re.sub('(꞉)(?!' + vowelsAll + ')', r'\1' + 'a', Strng)
+    #print(Strng)
+    Strng = re.sub('(꞉)(?!ʰ)(?!' + vowelsAll + ')', r'\1' + 'a', Strng)
     ## avoid double /a/ just in case
     #Strng = Strng.replace('aa', 'a')
     #Strng = re.sub(consonantsAll + '(?!' + vowelsAll + ')', r'\1' + 'a', Strng)
 
-
     #print(Strng)
 
     return Strng
@@ -2023,6 +2034,9 @@ def MalayalamChillu(Strng, reverse=False, preserve=False):
             Strng = re.sub(ListC + GM.VedicSvaras + '('+ConVir[i]+')'+'(?=(['+''.join(CList[i])+'])' + vir + r'\4' + ')',r'\1\2' + Chillus[i],Strng)
 
 
+        ## remove _ appearing due to the preserve chillu option
+        Strng = re.sub('(?<!ത്)ˍ', '', Strng)
+
     else:
         if preserve:
             for x,y in zip(Chillus, ConVir):
@@ -2110,8 +2124,16 @@ def GurmukhiTippiGemination(Strng):
 
     return Strng
 
+def BengaliConjunctVB(Strng):
+    ## kva / kba will be rendered the same
+    Strng = Strng.replace('\u09CD\u200C\u09AC', '\u09CD\u09AC')
+    Strng = khandatabatova(Strng)
+
+    return Strng
+
 def khandatabatova(Strng):
-    Strng = Strng.replace('ৎব', 'ত্ৱ')
+    Strng = Strng.replace('ৎব', 'ত্ব')
+    Strng = Strng.replace('ৎ\u200Cব', 'ত্ব')
 
     return Strng
 
@@ -2151,6 +2173,7 @@ def KhandaTa(Strng,Target, reverse=False): #Check for Bhakt - Khanda Ta not form
     ListC = '|'.join([GM.CrunchList('ConsonantMap', Target)[x] for x in [15,16,19,27,24,25,26,28]] + ['ৰ', 'য়'])
     if not reverse:
         Strng = re.sub('(?<!' + vir + ')' + '('+ta+')'+'('+vir+')'+'(?!'+ListC+')',khandata, Strng)
+        Strng = Strng.replace('ৎˍ', 'ৎ')
     else:
         Strng = Strng.replace(khandata, ta + vir)
 
